@@ -3,6 +3,5 @@ use HTTP::Proxy qw( :log );
 use strict;
 
 # a very simple proxy
-my $proxy = HTTP::Proxy->new;
-$proxy->logmask( shift || NONE );
+my $proxy = HTTP::Proxy->new(@ARGV);
 $proxy->start;
