@@ -1,5 +1,5 @@
 package HTTP::Proxy;
-$HTTP::Proxy::VERSION = '0.302';
+$HTTP::Proxy::VERSION = '0.303';
 use HTTP::Daemon;
 use HTTP::Date qw(time2str);
 use LWP::UserAgent;
@@ -7,10 +7,11 @@ use LWP::ConnCache;
 use Fcntl ':flock';         # import LOCK_* constants
 use IO::Select;
 use Sys::Hostname;          # hostname()
+use Socket qw( SOL_SOCKET SO_SNDBUF SO_RCVBUF );
 use Carp;
 
 use strict;
-use vars qw( $VERSION $AUTOLOAD @METHODS
+use vars qw( $VERSION @METHODS
              @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS );
 
 require Exporter;
@@ -89,7 +90,6 @@ sub new {
         port     => 8080,
         stash    => {},
         timeout  => 60,
-        via      => hostname() . " (HTTP::Proxy/$VERSION)",
         x_forwarded_for => 1,
     );
 
@@ -115,6 +115,10 @@ sub new {
     $self->{$_} = exists $params{$_} ? delete( $params{$_} ) : $defaults{$_}
       for keys %defaults;
 
+    if (!defined $self->{via}) {
+	$self->{via} = hostname() . ($self->{port} != 80 ? ':' . $self->{port} : '') . " (HTTP::Proxy/$VERSION)";
+    }
+
     # choose an engine with the remaining parameters
     $self->{engine} = HTTP::Proxy::Engine->new( %params, proxy => $self );
     $self->log( PROXY, "PROXY", "Selected engine " . ref $self->{engine} );
@@ -595,6 +599,9 @@ sub _handle_CONNECT {
         return $last;
     }
 
+    $upstream->setsockopt( SOL_SOCKET, SO_SNDBUF,
+        $conn->getsockopt( SOL_SOCKET, SO_RCVBUF ) );
+
     # send the response headers (FIXME more headers required?)
     my $response = HTTP::Response->new(200);
     $self->response($response);
